@@ -31,14 +31,17 @@ get_score_by_pgs_id <- function(pgs_id, limit = 20L, verbose = FALSE, warnings =
   resource <- '/rest/score'
   resource_urls <- sprintf("%s/%s", resource, pgs_id)
 
+  get_score <- purrr::slowly(f = get_score, rate = purrr::rate_delay(pause = delay()))
+
   purrr::map(
     resource_urls,
     get_score,
     limit = limit,
     warnings = warnings,
     verbose = verbose,
-    progress_bar = progress_bar
-  ) %>%
+    progress_bar = FALSE,
+    .progress = progress_bar
+  ) |>
     purrr::pmap(dplyr::bind_rows)
 }
 
@@ -47,14 +50,17 @@ get_score_by_pubmed_id <- function(pubmed_id, limit = 20L, verbose = FALSE, warn
   resource <- '/rest/score/search'
   resource_urls <- sprintf("%s?pmid=%s", resource, pubmed_id)
 
+  get_score <- purrr::slowly(f = get_score, rate = purrr::rate_delay(pause = delay()))
+
   purrr::map(
     resource_urls,
     get_score,
     limit = limit,
     warnings = warnings,
     verbose = verbose,
-    progress_bar = progress_bar
-  ) %>%
+    progress_bar = FALSE,
+    .progress = progress_bar
+  ) |>
     purrr::pmap(dplyr::bind_rows)
 }
 
@@ -63,14 +69,17 @@ get_score_by_trait_id <- function(efo_id, limit = 20L, verbose = FALSE, warnings
   resource <- '/rest/score/search'
   resource_urls <- sprintf("%s?trait_id=%s", resource, efo_id)
 
+  get_score <- purrr::slowly(f = get_score, rate = purrr::rate_delay(pause = delay()))
+
   purrr::map(
     resource_urls,
     get_score,
     limit = limit,
     warnings = warnings,
     verbose = verbose,
-    progress_bar = progress_bar
-  ) %>%
+    progress_bar = FALSE,
+    .progress = progress_bar
+  ) |>
     purrr::pmap(dplyr::bind_rows)
 }
 
@@ -143,21 +152,21 @@ get_scores <- function(pgs_id = NULL,
     list_of_scores[['get_score_by_pgs_id']] <-
     get_score_by_pgs_id(pgs_id = pgs_id,
                         verbose = verbose,
-                        warnings = warnings) %>%
+                        warnings = warnings) |>
     coerce_to_s4_scores()
 
   if (!rlang::is_null(efo_id))
     list_of_scores[['get_score_by_trait_id']] <-
     get_score_by_trait_id(efo_id = efo_id,
                         verbose = verbose,
-                        warnings = warnings) %>%
+                        warnings = warnings) |>
     coerce_to_s4_scores()
 
   if (!rlang::is_null(pubmed_id))
     list_of_scores[['get_score_by_pubmed_id']] <-
     get_score_by_pubmed_id(pubmed_id = pubmed_id,
                           verbose = verbose,
-                          warnings = warnings) %>%
+                          warnings = warnings) |>
     coerce_to_s4_scores()
 
   # If no criteria have been passed, i.e. all are NULL then got fetch all
