@@ -47,14 +47,17 @@ get_trait_by_efo_id <-
   flag <- ifelse(include_children, '1', '0')
   resource_urls <- sprintf("%s/%s?include_children=%s", resource, efo_id, flag)
 
+  get_trait <- purrr::slowly(f = get_trait, rate = purrr::rate_delay(pause = delay()))
+
   purrr::map(
     resource_urls,
     get_trait,
     limit = limit,
     warnings = warnings,
     verbose = verbose,
-    progress_bar = progress_bar
-  ) %>%
+    progress_bar = FALSE,
+    .progress = progress_bar
+  ) |>
     purrr::pmap(dplyr::bind_rows)
 }
 
@@ -81,14 +84,17 @@ get_trait_by_trait_term <-
       exact_term_flag
     )
 
+  get_trait <- purrr::slowly(f = get_trait, rate = purrr::rate_delay(pause = delay()))
+
   purrr::map(
     resource_urls,
     get_trait,
     limit = limit,
     warnings = warnings,
     verbose = verbose,
-    progress_bar = progress_bar
-  ) %>%
+    progress_bar = FALSE,
+    .progress = progress_bar
+  ) |>
     purrr::pmap(dplyr::bind_rows)
 }
 
@@ -177,7 +183,7 @@ get_traits <- function(efo_id = NULL,
       verbose = verbose,
       warnings = warnings,
       progress_bar = progress_bar
-    ) %>%
+    ) |>
     coerce_to_s4_traits()
 
   list_of_traits[['get_trait_by_trait_term']] <-
@@ -189,7 +195,7 @@ get_traits <- function(efo_id = NULL,
         verbose = verbose,
         warnings = warnings,
         progress_bar = progress_bar
-      ) %>%
+      ) |>
         coerce_to_s4_traits()
 
       if (identical(include_children, FALSE)) {
@@ -202,7 +208,7 @@ get_traits <- function(efo_id = NULL,
           verbose = verbose,
           warnings = warnings,
           progress_bar = progress_bar
-        ) %>%
+        ) |>
           coerce_to_s4_traits()
       }
     }
@@ -232,13 +238,16 @@ get_traits <- function(efo_id = NULL,
         # Get first all traits without children
         all_traits_wo_children <- get_trait_all(verbose = verbose, warnings = warnings)
         # Now get all traits, one by one, including children
-        get_trait_by_efo_id(efo_id = all_traits_wo_children$traits$efo_id,
-                            include_children = TRUE,
-                            verbose = verbose,
-                            warnings = warnings,
-                            progress_bar = progress_bar) %>%
-          coerce_to_s4_traits() %>%
-          return()
+        return(
+          get_trait_by_efo_id(
+            efo_id = all_traits_wo_children$traits$efo_id,
+            include_children = TRUE,
+            verbose = verbose,
+            warnings = warnings,
+            progress_bar = progress_bar
+          ) |>
+            coerce_to_s4_traits()
+        )
       }
     }
     else
